Index: tests/ImageFilterTest.cpp |
diff --git a/tests/ImageFilterTest.cpp b/tests/ImageFilterTest.cpp |
index fc709da5afb5c5b2c92eb95755504974d232a0ef..20bf0aa6d3a0aded8843c45cb5a04e571578d9da 100644 |
--- a/tests/ImageFilterTest.cpp |
+++ b/tests/ImageFilterTest.cpp |
@@ -859,12 +859,10 @@ DEF_TEST(ImageFilterCrossProcessPictureImageFilter, reporter) { |
canvas.clear(0x0); |
canvas.drawPicture(crossProcessPicture); |
pixel = *bitmap.getAddr32(0, 0); |
-#ifdef SK_DISALLOW_CROSSPROCESS_PICTUREIMAGEFILTERS |
- // The result here should not be green, since the filter draws nothing. |
- REPORTER_ASSERT(reporter, pixel != SK_ColorGREEN); |
-#else |
- REPORTER_ASSERT(reporter, pixel == SK_ColorGREEN); |
-#endif |
+ // If the security precautions are enabled, the result here should not be green, since the |
+ // filter draws nothing. |
+ REPORTER_ASSERT(reporter, SkPicture::PictureIOSecurityPrecautionsEnabled() |
+ ? pixel != SK_ColorGREEN : pixel == SK_ColorGREEN); |
} |
DEF_TEST(ImageFilterClippedPictureImageFilter, reporter) { |